@@ -19,8 +19,8 @@ import zlib
 from django.utils.encoding import smart_str
 
 from sentry.conf import settings
-# from sentry.exceptions import InvalidData, InvalidInterface
-from sentry.models import ProjectMember
+from sentry.exceptions import InvalidInterface, InvalidData, InvalidTimestamp
+from sentry.models import Group, Project, ProjectKey, TeamMember, Team
 from sentry.plugins import plugins
 from sentry.tasks.store import store_event
 from sentry.utils import is_float, json
@@ -29,9 +29,25 @@ from sentry.utils.queue import maybe_delay
 
 logger = logging.getLogger('sentry.errors.coreapi')
 
+RESERVED_FIELDS = (
+    'project',
+    'event_id',
+    'message',
+    'checksum',
+    'culprit',
+    'level',
+    'time_spent',
+    'logger',
+    'server_name',
+    'site',
+    'timestamp',
+    'extra',
+    'modules',
+)
 
-class InvalidTimestamp(ValueError):
-    pass
+REQUIRED_FIELDS = (
+    'message',
+)
 
 
 class APIError(Exception):
@@ -76,17 +92,28 @@ def project_from_auth_vars(auth_vars, data):
 
     if api_key:
         try:
-            pm = ProjectMember.objects.get_from_cache(public_key=api_key)
-        except ProjectMember.DoesNotExist:
+            pk = ProjectKey.objects.get_from_cache(public_key=api_key)
+        except ProjectKey.DoesNotExist:
             raise APIForbidden('Invalid signature')
 
-        if not pm.is_active or pm.user and not pm.user.is_active:
-            raise APIUnauthorized('Account is not active')
+        project = Project.objects.get_from_cache(pk=pk.project_id)
+        secret_key = pk.secret_key
 
-        project = pm.project
-        secret_key = pm.secret_key
+        if pk.user:
+            try:
+                team = Team.objects.get_from_cache(pk=project.team_id)
+            except Team.DoesNotExist:
+                raise APIUnauthorized('Member does not have access to project')
 
-        result = plugins.first('has_perm', pm.user, 'create_event', pm.project)
+            try:
+                tm = TeamMember.objects.get(team=team, user=pk.user, is_active=True)
+            except TeamMember.DoesNotExist:
+                raise APIUnauthorized('Member does not have access to project')
+
+            if not pk.user.is_active:
+                raise APIUnauthorized('Account is not active')
+
+        result = plugins.first('has_perm', tm.user, 'create_event', project)
         if result is False:
             raise APIUnauthorized()
     else:
@@ -118,21 +145,33 @@ def project_from_api_key_and_id(api_key, project_id):
     a project instance or throws APIUnauthorized.
     """
     try:
-        pm = ProjectMember.objects.get_from_cache(public_key=api_key)
-    except ProjectMember.DoesNotExist:
+        pk = ProjectKey.objects.get_from_cache(public_key=api_key)
+    except ProjectKey.DoesNotExist:
+        raise APIUnauthorized('Invalid api key')
+
+    if str(pk.project_id) != str(project_id):
         raise APIUnauthorized()
 
-    if str(pm.project_id) != str(project_id):
-        raise APIUnauthorized()
+    project = Project.objects.get_from_cache(pk=pk.project_id)
 
-    if not pm.is_active or pm.user and not pm.user.is_active:
-        raise APIUnauthorized('Account is not active')
+    if pk.user:
+        team = Team.objects.get_from_cache(pk=project.team_id)
 
-    result = plugins.first('has_perm', pm.user, 'create_event', pm.project)
+        try:
+            tm = TeamMember.objects.get(team=team, user=pk.user, is_active=True)
+        except TeamMember.DoesNotExist:
+            raise APIUnauthorized('Member does not have access to project')
+
+        if not pk.user.is_active:
+            raise APIUnauthorized('Account is not active')
+
+        tm.project = project
+
+    result = plugins.first('has_perm', tm.user, 'create_event', project)
     if result is False:
         raise APIUnauthorized()
 
-    return pm.project
+    return project
 
 
 def project_from_id(request):
@@ -144,21 +183,29 @@ def project_from_id(request):
         raise APIUnauthorized('Account is not active')
 
     try:
-        pm = ProjectMember.objects.get(
+        project = Project.objects.get_from_cache(pk=request.GET['project_id'])
+    except Project.DoesNotExist:
+        raise APIUnauthorized('Invalid project')
+
+    try:
+        team = Team.objects.get_from_cache(pk=project.team_id)
+    except Project.DoesNotExist:
+        raise APIUnauthorized('Member does not have access to project')
+
+    try:
+        TeamMember.objects.get(
             user=request.user,
-            project=request.GET['project_id'],
+            team=team,
+            is_active=True,
         )
-    except ProjectMember.DoesNotExist:
-        raise APIUnauthorized()
+    except TeamMember.DoesNotExist:
+        raise APIUnauthorized('Member does not have access to project')
 
-    if not pm.is_active:
-        raise APIUnauthorized()
-
-    result = plugins.first('has_perm', request.user, 'create_event', pm.project)
+    result = plugins.first('has_perm', request.user, 'create_event', project)
     if result is False:
         raise APIUnauthorized()
 
-    return pm.project
+    return project
 
 
 def decode_and_decompress_data(encoded_data):
@@ -221,14 +268,51 @@ def process_data_timestamp(data):
     return data
 
 
-def validate_data(project, data):
+def validate_data(project, data, client=None):
+    for k in REQUIRED_FIELDS:
+        if not data.get(k):
+            raise InvalidData('Missing required parameter: %r' % k)
+
     ensure_valid_project_id(project, data)
 
     if 'event_id' not in data:
         data['event_id'] = uuid.uuid4().hex
 
     if 'timestamp' in data:
-        process_data_timestamp(data)
+        try:
+            process_data_timestamp(data)
+        except InvalidTimestamp:
+            # Log the error, remove the timestamp, and continue
+            logger.error('Client %r passed an invalid value for timestamp %r' % (
+                data['timestamp'],
+                client or '<unknown client>',
+            ))
+            del data['timestamp']
+
+    if data.get('modules') and type(data['modules']) != dict:
+        raise InvalidData('Invalid type for \'modules\': must be a mapping')
+
+    for k, v in data.iteritems():
+        if k in RESERVED_FIELDS:
+            continue
+
+        if '.' not in k:
+            raise InvalidInterface('%r is not a valid interface name' % k)
+
+        try:
+            interface = Group.objects.module_cache[k]
+        except (ImportError, AttributeError), e:
+            raise InvalidInterface('%r is not a valid interface name: %s' % (k, e))
+
+        try:
+            data[k] = interface(**v).serialize()
+        except Exception, e:
+            raise InvalidData('Unable to validate interface, %r: %s' % (k, e))
+
+    level = data.get('level') or settings.DEFAULT_LOG_LEVEL
+    if isinstance(level, basestring) and not level.isdigit():
+        # assume it's something like 'warn'
+        data['level'] = settings.LOG_LEVEL_REVERSE_MAP[level]
 
     return data
 
