@@ -80,8 +80,7 @@ def manage_projects(request):
 
 @requires_admin
 def manage_users(request):
-    user_list = User.objects.annotate(num_projects=Count('sentry_project_set'))\
-                .order_by('-date_joined')
+    user_list = User.objects.all().order_by('-date_joined')
 
     user_query = request.GET.get('uquery')
     if user_query:
@@ -97,8 +96,6 @@ def manage_users(request):
         order_by = '-last_login'
     elif sort == 'name':
         order_by = 'first_name'
-    elif sort == 'projects':
-        order_by = '-num_projects'
 
     user_list = user_list.order_by(order_by)
 
@@ -134,7 +131,8 @@ def create_new_user(request):
                 owner=user,
                 name='New Project',
             )
-            member = project.member_set.get()
+            member = project.member_set.get(user=user)
+            key = project.key_set.get(user=user)
 
         if form.cleaned_data['send_welcome_mail']:
             context = {
@@ -146,7 +144,7 @@ def create_new_user(request):
                 context.update({
                     'project': project,
                     'member': member,
-                    'dsn': member.get_dsn(),
+                    'dsn': key.get_dsn(),
                 })
             body = render_to_string('sentry/emails/welcome_mail.txt', context, request)
 
